==> openshift-model-miscellaneous-6.5.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/BMCDetailsFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BMCDetailsFluentImpl<A extends BMCDetailsFluent<A>> extends BaseFluent<A> implements BMCDetailsFluent<A>{
  public BMCDetailsFluentImpl() {
  }
  public BMCDetailsFluentImpl(BMCDetails instance) {
    this.withAddress(instance.getAddress()); 
    this.withCredentialsName(instance.getCredentialsName()); 
    this.withDisableCertificateVerification(instance.getDisableCertificateVerification()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String address;
  private String credentialsName;
  private Boolean disableCertificateVerification;
  private Map<String,Object> additionalProperties;
  public String getAddress() {
    return this.address;
  }
  public A withAddress(String address) {
    this.address=address; return (A) this;
  }
  public Boolean hasAddress() {
    return this.address != null;
  }
  public String getCredentialsName() {
    return this.credentialsName;
  }
  public A withCredentialsName(String credentialsName) {
    this.credentialsName=credentialsName; return (A) this;
  }
  public Boolean hasCredentialsName() {
    return this.credentialsName != null;
  }
  public Boolean getDisableCertificateVerification() {
    return this.disableCertificateVerification;
  }
  public A withDisableCertificateVerification(Boolean disableCertificateVerification) {
    this.disableCertificateVerification=disableCertificateVerification; return (A) this;
  }
  public Boolean hasDisableCertificateVerification() {
    return this.disableCertificateVerification != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BMCDetailsFluentImpl that = (BMCDetailsFluentImpl) o;
    if (address != null ? !address.equals(that.address) :that.address != null) return false;
    if (credentialsName != null ? !credentialsName.equals(that.credentialsName) :that.credentialsName != null) return false;
    if (disableCertificateVerification != null ? !disableCertificateVerification.equals(that.disableCertificateVerification) :that.disableCertificateVerification != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(address,  credentialsName,  disableCertificateVerification,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (address != null) { sb.append("address:"); sb.append(address + ","); }
    if (credentialsName != null) { sb.append("credentialsName:"); sb.append(credentialsName + ","); }
    if (disableCertificateVerification != null) { sb.append("disableCertificateVerification:"); sb.append(disableCertificateVerification + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withDisableCertificateVerification() {
    return withDisableCertificateVerification(true);
  }
  
}

==> openshift-model-miscellaneous-6.7.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/BMCDetailsFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BMCDetailsFluentImpl<A extends BMCDetailsFluent<A>> extends BaseFluent<A> implements BMCDetailsFluent<A>{
  public BMCDetailsFluentImpl() {
  }
  public BMCDetailsFluentImpl(BMCDetails instance) {
    if (instance != null) {
      this.withAddress(instance.getAddress());
      this.withCredentialsName(instance.getCredentialsName());
      this.withDisableCertificateVerification(instance.getDisableCertificateVerification());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String address;
  private String credentialsName;
  private Boolean disableCertificateVerification;
  private Map<String,Object> additionalProperties;
  public String getAddress() {
    return this.address;
  }
  public A withAddress(String address) {
    this.address=address; return (A) this;
  }
  public Boolean hasAddress() {
    return this.address != null;
  }
  public String getCredentialsName() {
    return this.credentialsName;
  }
  public A withCredentialsName(String credentialsName) {
    this.credentialsName=credentialsName; return (A) this;
  }
  public Boolean hasCredentialsName() {
    return this.credentialsName != null;
  }
  public Boolean getDisableCertificateVerification() {
    return this.disableCertificateVerification;
  }
  public A withDisableCertificateVerification(Boolean disableCertificateVerification) {
    this.disableCertificateVerification=disableCertificateVerification; return (A) this;
  }
  public Boolean hasDisableCertificateVerification() {
    return this.disableCertificateVerification != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BMCDetailsFluentImpl that = (BMCDetailsFluentImpl) o;
    if (!java.util.Objects.equals(address, that.address)) return false;

    if (!java.util.Objects.equals(credentialsName, that.credentialsName)) return false;

    if (!java.util.Objects.equals(disableCertificateVerification, that.disableCertificateVerification)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(address,  credentialsName,  disableCertificateVerification,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (address != null) { sb.append("address:"); sb.append(address + ","); }
    if (credentialsName != null) { sb.append("credentialsName:"); sb.append(credentialsName + ","); }
    if (disableCertificateVerification != null) { sb.append("disableCertificateVerification:"); sb.append(disableCertificateVerification + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withDisableCertificateVerification() {
    return withDisableCertificateVerification(true);
  }
  
}
